@@ -29,9 +29,9 @@ def run_flynt_cli(arglist: Optional[List[str]] = None) -> int:
     verbosity_group.add_argument(
         "-v",
         "--verbose",
-        action="store_true",
+        action="count",
         help="run with verbose output",
-        default=False,
+        default=0,
     )
     verbosity_group.add_argument(
         "-q",
@@ -112,7 +112,7 @@ def run_flynt_cli(arglist: Optional[List[str]] = None) -> int:
         action="store_true",
         default=False,
         help="Replace string concatenations (defined as + operations involving string literals) "
-        "with f-strings. Available only if flynt is installed with 3.8+ interpreter.",
+        "with f-strings. Available only if flynt is installed with a 3.9+ interpreter.",
     )
 
     parser.add_argument(
@@ -121,7 +121,7 @@ def run_flynt_cli(arglist: Optional[List[str]] = None) -> int:
         action="store_true",
         default=False,
         help="Replace static joins (where the joiner is a string literal and the joinee is a static-length list) "
-        "with f-strings. Available only if flynt is installed with 3.8+ interpreter.",
+        "with f-strings. Available only if flynt is installed with a 3.9+ interpreter.",
     )
 
     parser.add_argument(
@@ -135,9 +135,12 @@ def run_flynt_cli(arglist: Optional[List[str]] = None) -> int:
     parser.add_argument(
         "-a",
         "--aggressive",
-        action="store_true",
-        default=False,
-        help="Include conversions with potentially changed behavior.",
+        action="count",
+        default=0,
+        help=(
+            "Include conversions with potentially changed behavior. "
+            "Use -aa to omit int() wrapping for %%d conversions."
+        ),
     )
 
     parser.add_argument(
@@ -148,6 +151,14 @@ def run_flynt_cli(arglist: Optional[List[str]] = None) -> int:
         help="ignore files with given strings in it's absolute path.",
     )
 
+    parser.add_argument(
+        "-nb",
+        "--notebook",
+        action="store_true",
+        default=False,
+        help="Also search and transform Jupyter notebooks (.ipynb files). Warning: feature in alpha and was not thoroughly tested.",
+    )
+
     parser.add_argument(
         "src",
         action="store",
@@ -164,6 +175,12 @@ def run_flynt_cli(arglist: Optional[List[str]] = None) -> int:
         default=False,
         help="Print the current version number and exit.",
     )
+    parser.add_argument(
+        "--report",
+        action="store_true",
+        default=False,
+        help="Show detailed conversion report",
+    )
     args = parser.parse_args(arglist)
     if args.stdout and args.verbose:
         parser.error("--stdout should not be used with -v/--verbose")
@@ -176,16 +193,16 @@ def run_flynt_cli(arglist: Optional[List[str]] = None) -> int:
         parser.print_usage()
         return 1
 
-    if args.transform_concats and sys.version_info < (3, 8):
+    if args.transform_concats and sys.version_info < (3, 9):
         raise Exception(
             f"""Transforming string concatenations is only possible with flynt
-                installed to a python3.8+ interpreter. Currently using {sys.version_info}.""",
+                installed to a python3.9+ interpreter. Currently using {sys.version_info}.""",
         )
 
-    if args.transform_joins and sys.version_info < (3, 8):
+    if args.transform_joins and sys.version_info < (3, 9):
         raise Exception(
             f"""Transforming joins is only possible with flynt
-                installed to a python3.8+ interpreter. Currently using {sys.version_info}.""",
+                installed to a python3.9+ interpreter. Currently using {sys.version_info}.""",
         )
 
     logging.basicConfig(
@@ -194,8 +211,10 @@ def run_flynt_cli(arglist: Optional[List[str]] = None) -> int:
     )
 
     state = state_from_args(args)
-    if args.verbose:
-        logging.getLogger("flynt").setLevel(logging.DEBUG)
+    if args.verbose > 0:
+        logging.getLogger("flynt").setLevel(
+            logging.DEBUG if args.verbose > 1 else logging.INFO
+        )
 
     if args.string:
         content = " ".join(args.src)
@@ -260,4 +279,6 @@ def state_from_args(args) -> State:
         transform_format=args.transform_format,
         transform_join=args.transform_joins,
         transform_percent=args.transform_percent,
+        report=args.report,
+        process_notebooks=args.notebook,
     )
